--[[
Quests Object
	name: name of quest category (quest section name)
	questTypes:
		name : e.g. World Boss
		quest names -> list of names of questTypes, e.g. Boss1, Boss2
--]]
local Info = {}
DQT.Info = Info
local QUEST_TYPE_ENUM = DQT.Quest.QUEST_TYPE_ENUM
local Quest = DQT.Quest.Quest
local QuestType = DQT.Quest.QuestType
local QuestSection = DQT.Quest.QuestSection
local Utils = DQT.Utils
local TimerQuest = DQT.Timer.TimerQuest
local TimerSection = DQT.Timer.TimerSection
local TIMER_TYPE = DQT.Timer.TIMER_TYPE

-- helper function for Quest:new when name and display name both need to be converted with GetString
local function newQuest(siName, siDisplayName)
	return Quest:new(GetString(siName), siDisplayName and GetString(siDisplayName) or nil)
end

Info.CraftingQuests =
	QuestSection:new(
	GetString(DQT_CRAFTING),
	{
		QuestType:new(
			GetString(DQT_CLOTHING),
			QUEST_TYPE_ENUM.MISC,
			{newQuest(DQT_CRAFTING_WRITS_EQUIPMENT_CRAFTING_WRITS_02)}
		),
		QuestType:new(
			GetString(DQT_BLACKSMITHING),
			QUEST_TYPE_ENUM.MISC,
			{newQuest(DQT_CRAFTING_WRITS_EQUIPMENT_CRAFTING_WRITS_01)}
		),
		QuestType:new(
			GetString(DQT_WOODWORKING),
			QUEST_TYPE_ENUM.MISC,
			{newQuest(DQT_CRAFTING_WRITS_EQUIPMENT_CRAFTING_WRITS_04)}
		),
		QuestType:new(
			GetString(DQT_JEWELRY),
			QUEST_TYPE_ENUM.MISC,
			{newQuest(DQT_CRAFTING_WRITS_EQUIPMENT_CRAFTING_WRITS_03)}
		),
		QuestType:new(
			GetString(DQT_ALCHEMY),
			QUEST_TYPE_ENUM.MISC,
			{newQuest(DQT_CRAFTING_WRITS_CONSUMABLES_CRAFTING_WRITS_01)}
		),
		QuestType:new(
			GetString(DQT_ENCHANTING),
			QUEST_TYPE_ENUM.MISC,
			{newQuest(DQT_CRAFTING_WRITS_CONSUMABLES_CRAFTING_WRITS_02)}
		),
		QuestType:new(
			GetString(DQT_PROVISIONING),
			QUEST_TYPE_ENUM.MISC,
			{newQuest(DQT_CRAFTING_WRITS_CONSUMABLES_CRAFTING_WRITS_03)}
		)
	}
)

Info.SummersetQuests =
	QuestSection:new(
	GetString(DQT_SUMMERSET),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_SUMMERSET_QUESTS_BOUNTY_01, DQT_SUMMERSET_QUESTS_BOUNTY_01_DISPLAY),
				newQuest(DQT_SUMMERSET_QUESTS_BOUNTY_02, DQT_SUMMERSET_QUESTS_BOUNTY_02_DISPLAY),
				newQuest(DQT_SUMMERSET_QUESTS_BOUNTY_03, DQT_SUMMERSET_QUESTS_BOUNTY_03_DISPLAY),
				newQuest(DQT_SUMMERSET_QUESTS_BOUNTY_04, DQT_SUMMERSET_QUESTS_BOUNTY_04_DISPLAY),
				newQuest(DQT_SUMMERSET_QUESTS_BOUNTY_05, DQT_SUMMERSET_QUESTS_BOUNTY_05_DISPLAY),
				newQuest(DQT_SUMMERSET_QUESTS_BOUNTY_06, DQT_SUMMERSET_QUESTS_BOUNTY_06_DISPLAY)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_SUMMERSET_QUESTS_EXPLORATORY_01),
				newQuest(DQT_SUMMERSET_QUESTS_EXPLORATORY_02),
				newQuest(DQT_SUMMERSET_QUESTS_EXPLORATORY_03),
				newQuest(DQT_SUMMERSET_QUESTS_EXPLORATORY_04),
				newQuest(DQT_SUMMERSET_QUESTS_EXPLORATORY_05),
				newQuest(DQT_SUMMERSET_QUESTS_EXPLORATORY_06)
			}
		),
		QuestType:new(
			GetString(DQT_GEYSERS),
			QUEST_TYPE_ENUM.DOLMEN,
			{newQuest(DQT_SUMMERSET_QUESTS_ABYSSAL_GEYSERS_01)}
		)
	}
)

-- create Vvardenfell relic Quest object from variable like DQT_VVARDENFELL_QUESTS_RELICS_01
local function relicsQuest(questLangVar)
	local questName = GetString(questLangVar)
	return Quest:new(
		questName,
		Utils:stripPrefixes(
			questName,
			{
				GetString(DQT_VVARDENFELL_QUESTS_RELICS_PREFIX_1),
				GetString(DQT_VVARDENFELL_QUESTS_RELICS_PREFIX_2)
			}
		)
	)
end

Info.VvardenfellQuests =
	QuestSection:new(
	GetString(DQT_VVARDENFELL),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_VVARDENFELL_QUESTS_BOUNTY_01, DQT_VVARDENFELL_QUESTS_BOUNTY_01_DISPLAY),
				newQuest(DQT_VVARDENFELL_QUESTS_BOUNTY_02, DQT_VVARDENFELL_QUESTS_BOUNTY_02_DISPLAY),
				newQuest(DQT_VVARDENFELL_QUESTS_BOUNTY_03, DQT_VVARDENFELL_QUESTS_BOUNTY_03_DISPLAY),
				newQuest(DQT_VVARDENFELL_QUESTS_BOUNTY_04, DQT_VVARDENFELL_QUESTS_BOUNTY_04_DISPLAY),
				newQuest(DQT_VVARDENFELL_QUESTS_BOUNTY_05, DQT_VVARDENFELL_QUESTS_BOUNTY_05_DISPLAY),
				newQuest(DQT_VVARDENFELL_QUESTS_BOUNTY_06, DQT_VVARDENFELL_QUESTS_BOUNTY_06_DISPLAY)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_VVARDENFELL_QUESTS_EXPLORATORY_01),
				newQuest(DQT_VVARDENFELL_QUESTS_EXPLORATORY_02),
				newQuest(DQT_VVARDENFELL_QUESTS_EXPLORATORY_03),
				newQuest(DQT_VVARDENFELL_QUESTS_EXPLORATORY_04),
				newQuest(DQT_VVARDENFELL_QUESTS_EXPLORATORY_05),
				newQuest(DQT_VVARDENFELL_QUESTS_EXPLORATORY_06)
			}
		),
		QuestType:new(
			GetString(DQT_ASHLANDER_HUNT),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_VVARDENFELL_QUESTS_HUNT_01),
				newQuest(DQT_VVARDENFELL_QUESTS_HUNT_02),
				newQuest(DQT_VVARDENFELL_QUESTS_HUNT_03),
				newQuest(DQT_VVARDENFELL_QUESTS_HUNT_04),
				newQuest(DQT_VVARDENFELL_QUESTS_HUNT_05),
				newQuest(DQT_VVARDENFELL_QUESTS_HUNT_06),
				newQuest(DQT_VVARDENFELL_QUESTS_HUNT_07)
			}
		),
		QuestType:new(
			GetString(DQT_ASHLANDER_RELIC),
			QUEST_TYPE_ENUM.MISC,
			{
				relicsQuest(DQT_VVARDENFELL_QUESTS_RELICS_01),
				relicsQuest(DQT_VVARDENFELL_QUESTS_RELICS_02),
				relicsQuest(DQT_VVARDENFELL_QUESTS_RELICS_03),
				relicsQuest(DQT_VVARDENFELL_QUESTS_RELICS_04),
				relicsQuest(DQT_VVARDENFELL_QUESTS_RELICS_05),
				relicsQuest(DQT_VVARDENFELL_QUESTS_RELICS_06),
				relicsQuest(DQT_VVARDENFELL_QUESTS_RELICS_07)
			}
		)
	}
)

-- create fighters guild Quest object from variable like DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_01
local function fightersQuest(questLangVar)
	local questName = GetString(questLangVar)
	return Quest:new(
		questName,
		Utils:stripPrefixes(
			questName,
			{
				GetString(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_PREFIX_1),
				GetString(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_PREFIX_2),
				GetString(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_PREFIX_3),
				GetString(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_PREFIX_4)
			}
		)
	)
end

-- create mages guild Quest object from variable like DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_01
local function magesQuest(questLangVar)
	local questName = GetString(questLangVar)
	return Quest:new(
		questName,
		Utils:stripPrefixes(
			questName,
			{
				GetString(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_PREFIX_1),
				GetString(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_PREFIX_2),
				GetString(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_PREFIX_3),
				GetString(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_PREFIX_4)
			}
		)
	)
end

Info.GuildQuests =
	QuestSection:new(
	GetString(DQT_GUILD),
	{
		QuestType:new(
			GetString(DQT_FIGHTERS_GUILD),
			QUEST_TYPE_ENUM.DOLMEN,
			{
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_01),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_02),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_03),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_04),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_05),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_06),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_07),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_08),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_09),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_10),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_11),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_12),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_13),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_14),
				fightersQuest(DQT_GUILD_DAILY_QUESTS_FIGHTERS_GUILD_DAILY_QUESTS_15)
			}
		),
		QuestType:new(
			GetString(DQT_MAGES_GUILD),
			QUEST_TYPE_ENUM.DELVE,
			{
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_01),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_02),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_03),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_04),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_05),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_06),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_07),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_08),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_09),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_10),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_11),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_12),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_13),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_14),
				magesQuest(DQT_GUILD_DAILY_QUESTS_MAGES_GUILD_DAILY_QUESTS_15)
			}
		),
		QuestType:new(
			GetString(DQT_UNDAUNTED_DELVE),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_01),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_02),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_03),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_04),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_05),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_06),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_07),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_08),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_09),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_10),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_11),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_12),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_13),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_14),
				newQuest(DQT_GUILD_DAILY_QUESTS_UNDAUNTED_DAILY_QUESTS_15)
			}
		)
	}
)

-- create Cyrodilic Collections Quest object from variable like DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_01
--[[local function ccQuestType(questLangVar)
	return QuestType:new(GetString(questLangVar), QUEST_TYPE_ENUM.MISC, {Quest:new(GetString(questLangVar))})
end

Info.CyrodilicCollectionsQuests =
	QuestSection:new(
	GetString(DQT_CYRODILIC_COLLECTIONS),
	{
		ccQuestType(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_01),
		ccQuestType(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_02),
		ccQuestType(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_03),
		ccQuestType(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_04),
		ccQuestType(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_05),
		ccQuestType(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_06)
	}
)]]

--[[Info.LowerCraglorn =
	QuestSection:new(
	GetString(DQT_LOWER_CRAGLORN),
	{
		-- Added by DarkPhalanx
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_01),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_01)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_02),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_02)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_03),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_03)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_04),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_04)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_05),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_05)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_06),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_06)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_07),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_07)
			}
		)
	}
)

Info.UpperCraglorn =
	QuestSection:new(
	GetString(DQT_UPPER_CRAGLORN),
	{
		-- Added by DarkPhalanx
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_01),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_01)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_02),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_02)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_03),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_03)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_04),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_04)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_05),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_05)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_06),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_06)
			}
		),
		QuestType:new(
			GetString(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_07),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_07)
			}
		)
	}
)]]

Info.Craglorn =
	QuestSection:new(
	GetString(DQT_CRAGLORN),
	{
		QuestType:new(
			GetString(DQT_GROUP_PVE),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_01),
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_02),
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_03),
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_04),
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_05),
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_06),
				newQuest(DQT_CRAGLORN_QUESTS_LOWER_CRAGLORN_07),
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_01),
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_02),
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_03),
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_04),
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_05),
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_06),
				newQuest(DQT_CRAGLORN_QUESTS_UPPER_CRAGLORN_07)
			}
		)
	}
	)

Info.ClockworkCityQuests =
	QuestSection:new(
	GetString(DQT_CLOCKWORK_CITY),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_BOUNTY_01, DQT_CLOCKWORK_CITY_QUESTS_BOUNTY_01_DISPLAY),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_BOUNTY_02, DQT_CLOCKWORK_CITY_QUESTS_BOUNTY_02_DISPLAY)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_EXPLORATORY_01),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_EXPLORATORY_02),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_EXPLORATORY_03),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_EXPLORATORY_04),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_EXPLORATORY_05),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_EXPLORATORY_06)
			}
		),
		QuestType:new(
			GetString(DQT_TARNISHED),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_TARNISHED_01),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_TARNISHED_02),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_TARNISHED_03),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_TARNISHED_04),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_TARNISHED_05),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_TARNISHED_06)
			}
		),
		QuestType:new(
			GetString(DQT_BLACKFEATHER_COURT),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_BLACKFEATHER_COURT_01),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_BLACKFEATHER_COURT_02),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_BLACKFEATHER_COURT_03),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_BLACKFEATHER_COURT_04),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_BLACKFEATHER_COURT_05),
				newQuest(DQT_CLOCKWORK_CITY_QUESTS_BLACKFEATHER_COURT_06)
			}
		)
	}
)

Info.WrothgarQuests =
	QuestSection:new(
	GetString(DQT_WROTHGAR),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_01,
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_01_DISPLAY
				),
				newQuest(
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_02,
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_02_DISPLAY
				),
				newQuest(
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_03,
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_03_DISPLAY
				),
				newQuest(
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_04,
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_04_DISPLAY
				),
				newQuest(
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_05,
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_05_DISPLAY
				),
				newQuest(
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_06,
					DQT_WROTHGAR_QUESTS_GROUP_BOSS_DAILIES_06_DISPLAY
				)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_WROTHGAR_QUESTS_DELVE_DAILIES_01),
				newQuest(DQT_WROTHGAR_QUESTS_DELVE_DAILIES_02),
				newQuest(DQT_WROTHGAR_QUESTS_DELVE_DAILIES_03),
				newQuest(DQT_WROTHGAR_QUESTS_DELVE_DAILIES_04),
				newQuest(DQT_WROTHGAR_QUESTS_DELVE_DAILIES_05),
				newQuest(DQT_WROTHGAR_QUESTS_DELVE_DAILIES_06)
			}
		)
	}
)

-- create heist Quest object from variable like DQT_THIEVES_GUILD_LARCENY_QUESTS_HEISTS_01
local function heistQuest(questLangVar)
	local questName = GetString(questLangVar)
	return Quest:new(
		questName,
		Utils:stripPrefixes(
			questName,
			{
				GetString(DQT_THIEVES_GUILD_LARCENY_QUESTS_HEISTS_PREFIX_1),
				GetString(DQT_THIEVES_GUILD_LARCENY_QUESTS_HEISTS_PREFIX_2)
			}
		)
	)
end

Info.ThievesGuildQuests =
	QuestSection:new(
	GetString(DQT_THIEVES_GUILD),
	{
		QuestType:new(
			GetString(DQT_RYES_REACQUISITIONS),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_RYE_S_REACQUISITIONS_01),
				newQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_RYE_S_REACQUISITIONS_02),
				newQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_RYE_S_REACQUISITIONS_03),
				newQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_RYE_S_REACQUISITIONS_04)
			}
		),
		QuestType:new(
			GetString(DQT_HEIST),
			QUEST_TYPE_ENUM.MISC,
			{
				heistQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_HEISTS_01),
				heistQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_HEISTS_02),
				heistQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_HEISTS_03),
				heistQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_HEISTS_04),
				heistQuest(DQT_THIEVES_GUILD_LARCENY_QUESTS_HEISTS_05)
			}
		)
	}
)

-- create sacrament Quest object from variable like DQT_GOLD_COAST_QUESTS_DARK_BROTHERHOOD_SACRAMENTS_01
local function sacramentQuest(questLangVar)
	local questName = GetString(questLangVar)
	return Quest:new(
		questName,
		Utils:stripPrefixes(
			questName,
			{
				GetString(DQT_GOLD_COAST_QUESTS_DARK_BROTHERHOOD_SACRAMENTS_PREFIX)
			}
		)
	)
end

Info.DarkBrotherhoodQuests =
	QuestSection:new(
	GetString(DQT_DARK_BROTHERHOOD),
	{
		QuestType:new(
			GetString(DQT_GOLD_COAST_BOUNTY),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_GOLD_COAST_QUESTS_BOUNTIES_01, DQT_GOLD_COAST_QUESTS_BOUNTIES_01_DISPLAY),
				newQuest(DQT_GOLD_COAST_QUESTS_BOUNTIES_02, DQT_GOLD_COAST_QUESTS_BOUNTIES_02_DISPLAY),
				newQuest(DQT_GOLD_COAST_QUESTS_BOUNTIES_03, DQT_GOLD_COAST_QUESTS_BOUNTIES_03_DISPLAY),
				newQuest(DQT_GOLD_COAST_QUESTS_BOUNTIES_04, DQT_GOLD_COAST_QUESTS_BOUNTIES_04_DISPLAY)
			}
		),
		QuestType:new(
			GetString(DQT_SACRAMENT),
			QUEST_TYPE_ENUM.MISC,
			{
				sacramentQuest(DQT_GOLD_COAST_QUESTS_DARK_BROTHERHOOD_SACRAMENTS_01),
				sacramentQuest(DQT_GOLD_COAST_QUESTS_DARK_BROTHERHOOD_SACRAMENTS_02),
				sacramentQuest(DQT_GOLD_COAST_QUESTS_DARK_BROTHERHOOD_SACRAMENTS_03)
			}
		)
	}
)

Info.MurkmireQuests =
	QuestSection:new(
	GetString(DQT_MURKMIRE),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_MURKMIRE_QUESTS_BOUNTY_01),
				newQuest(DQT_MURKMIRE_QUESTS_BOUNTY_02),
				newQuest(DQT_MURKMIRE_QUESTS_BOUNTY_03),
				newQuest(DQT_MURKMIRE_QUESTS_BOUNTY_04),
				newQuest(DQT_MURKMIRE_QUESTS_BOUNTY_05),
				newQuest(DQT_MURKMIRE_QUESTS_BOUNTY_06)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_MURKMIRE_QUESTS_EXPLORATORY_01),
				newQuest(DQT_MURKMIRE_QUESTS_EXPLORATORY_02),
				newQuest(DQT_MURKMIRE_QUESTS_EXPLORATORY_03),
				newQuest(DQT_MURKMIRE_QUESTS_EXPLORATORY_04),
				newQuest(DQT_MURKMIRE_QUESTS_EXPLORATORY_05),
				newQuest(DQT_MURKMIRE_QUESTS_EXPLORATORY_06)
			}
		),
		QuestType:new(
			GetString(DQT_ROOT_WHISPER),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_MURKMIRE_QUESTS_ROOT_WHISPER_01),
				newQuest(DQT_MURKMIRE_QUESTS_ROOT_WHISPER_02),
				newQuest(DQT_MURKMIRE_QUESTS_ROOT_WHISPER_03),
				newQuest(DQT_MURKMIRE_QUESTS_ROOT_WHISPER_04),
				newQuest(DQT_MURKMIRE_QUESTS_ROOT_WHISPER_05)
			}
		),
		QuestType:new(
			GetString(DQT_PROLOGUE),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_01),
				newQuest(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_02),
				newQuest(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_03),
				newQuest(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_04),
				newQuest(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_05),
				newQuest(DQT_BLACK_MARSH_CYRODILIC_COLLECTIONS_06)
			}
		)
	}
)

-- create elsweyr prologue Quest object from variable like DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_01
local function elsweyrQuest(questLangVar)
	local questName = GetString(questLangVar)
	return Quest:new(
		questName,
		Utils:stripPrefixes(
			questName,
			{
				GetString(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_QUESTS_PREFIX_1),
				GetString(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_QUESTS_PREFIX_2),
				GetString(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_QUESTS_PREFIX_3),
				GetString(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_QUESTS_PREFIX_4)
			}
		)
	)
end

Info.ElsweyrQuests =
	QuestSection:new(
	GetString(DQT_ELSWEYR),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_ELSWEYR_QUESTS_BOUNTY_01),
				newQuest(DQT_ELSWEYR_QUESTS_BOUNTY_02),
				newQuest(DQT_ELSWEYR_QUESTS_BOUNTY_03),
				newQuest(DQT_ELSWEYR_QUESTS_BOUNTY_04),
				newQuest(DQT_ELSWEYR_QUESTS_BOUNTY_05)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_ELSWEYR_QUESTS_EXPLORATORY_01),
				newQuest(DQT_ELSWEYR_QUESTS_EXPLORATORY_02),
				newQuest(DQT_ELSWEYR_QUESTS_EXPLORATORY_03),
				newQuest(DQT_ELSWEYR_QUESTS_EXPLORATORY_04),
				newQuest(DQT_ELSWEYR_QUESTS_EXPLORATORY_05),
				newQuest(DQT_ELSWEYR_QUESTS_EXPLORATORY_06)
			}
		),
		QuestType:new(
			GetString(DQT_DRAGONHUNT),
			QUEST_TYPE_ENUM.DOLMEN,
			{
				newQuest(DQT_ELSWEYR_QUESTS_DRAGONHUNT_01)
			}
		),
		QuestType:new(
			GetString(DQT_PROLOGUE),
			QUEST_TYPE_ENUM.MISC,
			{
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_01),
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_02),
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_03),
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_04),
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_05),
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_06),
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_07),
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_08),
				elsweyrQuest(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_09)
			}
		)
	}
)

Info.ImperialCityQuests =
	QuestSection:new(
	GetString(DQT_IMPERIAL_CITY),
	{
		-- Added by DarkPhalanx
		QuestType:new(
			GetString(DQT_PVP),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_IMPERIAL_CITY_IMPERIAL_CITY_QUESTS_01),
				newQuest(DQT_IMPERIAL_CITY_IMPERIAL_CITY_QUESTS_02),
				newQuest(DQT_IMPERIAL_CITY_IMPERIAL_CITY_QUESTS_03),
				newQuest(DQT_IMPERIAL_CITY_IMPERIAL_CITY_QUESTS_04),
				newQuest(DQT_IMPERIAL_CITY_IMPERIAL_CITY_QUESTS_05),
				newQuest(DQT_IMPERIAL_CITY_IMPERIAL_CITY_QUESTS_06)
			}
		)
	}
)

Info.DragonHoldQuests =
	QuestSection:new(
	GetString(DQT_DRAGONHOLD),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_WORLDBOSS_01),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_WORLDBOSS_02),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_WORLDBOSS_03),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_WORLDBOSS_04),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_WORLDBOSS_05),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_WORLDBOSS_06)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_01),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_02),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_03),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_04),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_05),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_06)
			}
		),
		QuestType:new(
			GetString(DQT_DRAGONHUNT),
			QUEST_TYPE_ENUM.DOLMEN,
			{
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DRAGONHUNT_02)
			}
		),
		QuestType:new(
			GetString(DQT_NEW_MOON),
			QUEST_TYPE_ENUM.DOLMEN,
			{
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_07),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_08),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_09),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_10),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_11),
				newQuest(DQT_SOUTHERN_ELSWEYR_QUESTS_DELVE_12)
			}
		)
	}
)

Info.WesternSkyrimQuests =
	QuestSection:new(
	GetString(DQT_WESTERN_SKYRIM),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_WORLDBOSS_01),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_WORLDBOSS_02),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_WORLDBOSS_03),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_WORLDBOSS_04),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_WORLDBOSS_05),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_WORLDBOSS_06)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_DELVE_01),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_DELVE_02),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_DELVE_03),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_DELVE_04),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_DELVE_05),
				newQuest(DQT_WESTERN_SKYRIM_QUESTS_DELVE_06)
			}
		),
		QuestType:new(
			GetString(DQT_HARROWSTORM),
			QUEST_TYPE_ENUM.DOLMEN,
			{newQuest(DQT_WESTERN_SKYRIM_QUESTS_HARROWSTORM_01)}
		)
	}
)

Info.ReachQuests =
	QuestSection:new(
	GetString(DQT_THE_REACH),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_THE_REACH_QUESTS_WORLDBOSS_01),
				newQuest(DQT_THE_REACH_QUESTS_WORLDBOSS_02),
				newQuest(DQT_THE_REACH_QUESTS_WORLDBOSS_03),
				newQuest(DQT_THE_REACH_QUESTS_WORLDBOSS_04),
				newQuest(DQT_THE_REACH_QUESTS_WORLDBOSS_05),
				newQuest(DQT_THE_REACH_QUESTS_WORLDBOSS_06)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_THE_REACH_QUESTS_DELVE_01),
				newQuest(DQT_THE_REACH_QUESTS_DELVE_02),
				newQuest(DQT_THE_REACH_QUESTS_DELVE_03),
				newQuest(DQT_THE_REACH_QUESTS_DELVE_04),
				newQuest(DQT_THE_REACH_QUESTS_DELVE_05),
				newQuest(DQT_THE_REACH_QUESTS_DELVE_06)
			}
		),
		QuestType:new(
			GetString(DQT_RESISTANCE),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_THE_REACH_QUESTS_RESISTANCE_01),
				newQuest(DQT_THE_REACH_QUESTS_RESISTANCE_02),
				newQuest(DQT_THE_REACH_QUESTS_RESISTANCE_03),
				newQuest(DQT_THE_REACH_QUESTS_RESISTANCE_04),
				newQuest(DQT_THE_REACH_QUESTS_RESISTANCE_05),
				newQuest(DQT_THE_REACH_QUESTS_RESISTANCE_06),
				newQuest(DQT_THE_REACH_QUESTS_RESISTANCE_07)
			}
		),
		QuestType:new(
			GetString(DQT_HARROWSTORM),
			QUEST_TYPE_ENUM.DOLMEN,
			{newQuest(DQT_THE_REACH_QUESTS_HARROWSTORM_01)}
		)
	}
)

Info.BlackwoodQuests =
	QuestSection:new(
	GetString(DQT_BLACKWOOD),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_BLACKWOOD_QUESTS_WORLDBOSS_01),
				newQuest(DQT_BLACKWOOD_QUESTS_WORLDBOSS_02),
				newQuest(DQT_BLACKWOOD_QUESTS_WORLDBOSS_03),
				newQuest(DQT_BLACKWOOD_QUESTS_WORLDBOSS_04),
				newQuest(DQT_BLACKWOOD_QUESTS_WORLDBOSS_05),
				newQuest(DQT_BLACKWOOD_QUESTS_WORLDBOSS_06)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_BLACKWOOD_QUESTS_DELVE_01),
				newQuest(DQT_BLACKWOOD_QUESTS_DELVE_02),
				newQuest(DQT_BLACKWOOD_QUESTS_DELVE_03),
				newQuest(DQT_BLACKWOOD_QUESTS_DELVE_04),
				newQuest(DQT_BLACKWOOD_QUESTS_DELVE_05),
				newQuest(DQT_BLACKWOOD_QUESTS_DELVE_06)
			}
		)
	}
)

Info.DeadlandsQuests =
	QuestSection:new(
	GetString(DQT_DEADLANDS),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_DEADLANDS_QUESTS_WORLDBOSS_01),
				newQuest(DQT_DEADLANDS_QUESTS_WORLDBOSS_02),
				newQuest(DQT_DEADLANDS_QUESTS_WORLDBOSS_03),
				newQuest(DQT_DEADLANDS_QUESTS_WORLDBOSS_04),
				newQuest(DQT_DEADLANDS_QUESTS_WORLDBOSS_05),
				newQuest(DQT_DEADLANDS_QUESTS_WORLDBOSS_06)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_DEADLANDS_QUESTS_DELVE_01),
				newQuest(DQT_DEADLANDS_QUESTS_DELVE_02),
				newQuest(DQT_DEADLANDS_QUESTS_DELVE_03),
				newQuest(DQT_DEADLANDS_QUESTS_DELVE_04),
				newQuest(DQT_DEADLANDS_QUESTS_DELVE_05),
				newQuest(DQT_DEADLANDS_QUESTS_DELVE_06)
			}
		)
	}
)

Info.HighIsle =
	QuestSection:new(
	GetString(DQT_HIGH_ISLE),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_HIGH_ISLE_QUESTS_WORLDBOSS_01),
				newQuest(DQT_HIGH_ISLE_QUESTS_WORLDBOSS_02),
				newQuest(DQT_HIGH_ISLE_QUESTS_WORLDBOSS_03),
				newQuest(DQT_HIGH_ISLE_QUESTS_WORLDBOSS_04),
				newQuest(DQT_HIGH_ISLE_QUESTS_WORLDBOSS_05),
				newQuest(DQT_HIGH_ISLE_QUESTS_WORLDBOSS_06)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_HIGH_ISLE_QUESTS_DELVE_01),
				newQuest(DQT_HIGH_ISLE_QUESTS_DELVE_02),
				newQuest(DQT_HIGH_ISLE_QUESTS_DELVE_03),
				newQuest(DQT_HIGH_ISLE_QUESTS_DELVE_04),
				newQuest(DQT_HIGH_ISLE_QUESTS_DELVE_05),
				newQuest(DQT_HIGH_ISLE_QUESTS_DELVE_06)
			}
		),
		QuestType:new(
			GetString(DQT_VOLCANIC_VENTS),
			QUEST_TYPE_ENUM.DOLMEN,
			{
				newQuest(DQT_HIGH_ISLE_QUESTS_VOLCANIC_VENTS_01)
			}
		),
		QuestType:new(
			GetString(DQT_TALES_OF_TRIBUTE),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_TALES_OF_TRIBUTE_QUESTS_01),
				newQuest(DQT_TALES_OF_TRIBUTE_QUESTS_02)
			}
		)
	}
)

Info.Galen =
	QuestSection:new(
	GetString(DQT_GALEN),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_GALEN_QUESTS_WORLDBOSS_01),
				newQuest(DQT_GALEN_QUESTS_WORLDBOSS_02),
				newQuest(DQT_GALEN_QUESTS_WORLDBOSS_03),
				newQuest(DQT_GALEN_QUESTS_WORLDBOSS_04),
				newQuest(DQT_GALEN_QUESTS_WORLDBOSS_05),
				newQuest(DQT_GALEN_QUESTS_WORLDBOSS_06)
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_GALEN_QUESTS_DELVE_01),
				newQuest(DQT_GALEN_QUESTS_DELVE_02),
				newQuest(DQT_GALEN_QUESTS_DELVE_03),
				newQuest(DQT_GALEN_QUESTS_DELVE_04),
				newQuest(DQT_GALEN_QUESTS_DELVE_05),
				newQuest(DQT_GALEN_QUESTS_DELVE_06)
			}
		),
		QuestType:new(
			GetString(DQT_VOLCANIC_VENTS),
			QUEST_TYPE_ENUM.DOLMEN,
			{
				newQuest(DQT_GALEN_QUESTS_VOLCANIC_VENTS_01)
			}
		)
	}
)

Info.CyrodiilSettlements =
	QuestSection:new(
	GetString(DQT_CYRODIIL_PVE),
	{
		QuestType:new(
			GetString(DQT_BRUMA),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_01),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_02),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_03),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_04),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_05),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_06),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_07),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_08),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_09),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_BRUMA_10)
			}
		),
		QuestType:new(
			GetString(DQT_CHEYDINHAL),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_01),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_02),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_03),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_04),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_05),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_06),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_07),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_08),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_09),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHEYDINHAL_10)
			}
		),
		QuestType:new(
			GetString(DQT_CHORROL),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_01),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_02),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_03),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_04),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_05),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_06),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_07),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_08),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_09),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CHORROL_AND_WEYNON_PRIORY_10)
			}
		),
		QuestType:new(
			GetString(DQT_CROPSFORD),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_01),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_02),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_03),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_04),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_05),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_06),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_07),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_08),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_CROPSFORD_09)
			}
		),
		QuestType:new(
			GetString(DQT_VLASTARUS),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_01),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_02),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_03),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_04),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_05),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_06),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_07),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_08),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_09),
				newQuest(DQT_CYRODIIL_CYRODIIL_SETTLEMENT_QUESTS_VLASTARUS_10)
			}
		)
	}
)

-- create bounty Quest object from variable like DQT_CYRODIIL_FIGHTERS_GUILD_BOUNTY_QUESTS_01
local function bountyQuest(questLangVar)
	local questName = GetString(questLangVar)
	return Quest:new(
		questName,
		Utils:stripPrefixes(
			questName,
			{
				GetString(DQT_CYRODIIL_FIGHTERS_GUILD_BOUNTY_QUESTS_PREFIX)
			}
		)
	)
end

Info.CyrodiilPVP =
	QuestSection:new(
	GetString(DQT_CYRODIIL_PVP),
	{
		QuestType:new(
			GetString(DQT_CYRODIIL_FIGHTERS_GUILD),
			QUEST_TYPE_ENUM.MISC,
			{
				bountyQuest(DQT_CYRODIIL_FIGHTERS_GUILD_BOUNTY_QUESTS_01),
				bountyQuest(DQT_CYRODIIL_FIGHTERS_GUILD_BOUNTY_QUESTS_02),
				bountyQuest(DQT_CYRODIIL_FIGHTERS_GUILD_BOUNTY_QUESTS_03),
				bountyQuest(DQT_CYRODIIL_FIGHTERS_GUILD_BOUNTY_QUESTS_04)
			}
		),
		QuestType:new(
			GetString(DQT_CYRODIIL_BATTLE_MISSIONS),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_01),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_02),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_03),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_04),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_05),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_06),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_07),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_08),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_09),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_10),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_11),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_12),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_13),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_14),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_15),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_16),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_17),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_18),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_19),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_20),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_21),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_22),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_23),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_24),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_25),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_26),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_27),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_28),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_29),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_30),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_31),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_32),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_33),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_34),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_35),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_36),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_37),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_38),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_39),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_40),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_41),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_42),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_43),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_44),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_45),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_46),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_47),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_48),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_49),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_50),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_51),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_52),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_53),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BATTLE_MISSIONS_54)
			}
		),
		QuestType:new(
			GetString(DQT_CYRODIIL_BOUNTY_MISSIONS),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BOUNTY_MISSIONS_01),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BOUNTY_MISSIONS_02),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BOUNTY_MISSIONS_03),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BOUNTY_MISSIONS_04),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BOUNTY_MISSIONS_05),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BOUNTY_MISSIONS_06),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_BOUNTY_MISSIONS_07),
			}
		),
		QuestType:new(
			GetString(DQT_CYRODIIL_CONQUEST_MISSION),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_PVP_QUESTS_CONQUEST_MISSIONS_01),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_CONQUEST_MISSIONS_02),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_CONQUEST_MISSIONS_03),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_CONQUEST_MISSIONS_04)
			}
		),
		QuestType:new(
			GetString(DQT_CYRODIIL_SCOUTING_MISSIONS),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_01),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_02),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_03),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_04),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_05),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_06),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_07),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_08),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_09),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_10),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_11),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_12),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_13),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_14),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_15),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_16),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_17),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_18),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_19),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_20),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_21),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_22),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_23),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_24),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_25),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_26),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_27),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_28),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_29),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_30),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_31),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_32),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_33),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_34),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_35),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_36),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_37),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_38),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_39),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_40),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_41),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_42),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_43),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_44),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_45),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_46),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_47),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_48),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_49),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_50),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_51),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_52),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_53),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_54),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_55),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_56),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_57),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_58),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_59),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_60),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_61),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_62),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_63),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_64),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_65),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_66),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_67),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_68),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_69),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_70),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_71),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_SCOUTING_MISSIONS_72)
			}
		),
		QuestType:new(
			GetString(DQT_CYRODIIL_WARFRONT_MISSION),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_01),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_02),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_03),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_04),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_05),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_06),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_07),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_08),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_09),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_10),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_11),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_WARFRONT_MISSIONS_12)
			}
		),
		QuestType:new(
			GetString(DQT_CYRODIIL_ELDER_SCROLL),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_CYRODIIL_PVP_QUESTS_ELDER_SCROLLS_MISSIONS_01),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_ELDER_SCROLLS_MISSIONS_02),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_ELDER_SCROLLS_MISSIONS_03),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_ELDER_SCROLLS_MISSIONS_04),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_ELDER_SCROLLS_MISSIONS_05),
				newQuest(DQT_CYRODIIL_PVP_QUESTS_ELDER_SCROLLS_MISSIONS_06)
			}
		)
	}
)

-- create Elsweyr Prologue Quest object from variable like DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_01
--[[local function epQuestType(questLangVar, displayLangVar)
	return QuestType:new(GetString(displayLangVar), QUEST_TYPE_ENUM.MISC, {Quest:new(GetString(questLangVar))})
end--]]
--[[local function epQuestType(questLangVar)
	return QuestType:new(GetString(questLangVar), QUEST_TYPE_ENUM.MISC, {Quest:new(GetString(questLangVar))})
end

Info.ElsweyrPrologueQuests =
	QuestSection:new(
	GetString(DQT_ELSWEYR_PROLOGUE),
	{
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_01, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_01_DISPLAY),
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_02, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_02_DISPLAY),
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_03, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_03_DISPLAY),
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_04, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_04_DISPLAY),
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_05, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_05_DISPLAY),
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_06, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_06_DISPLAY),
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_07, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_07_DISPLAY),
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_08, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_08_DISPLAY),
		epQuestType(DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_09, DQT_NORTHERN_ELSWEYR_DEFENSE_FORCE_09_DISPLAY)
	}
)]]

-- create nymic Quest object from variable like DQT_NECROM_QUESTS_BASTION_NYMIC_01
local function nymicQuest(questLangVar)
	local questName = GetString(questLangVar)
	return Quest:new(
		questName,
		Utils:stripPrefixes(
			questName,
			{
				GetString(DQT_NECROM_QUESTS_BASTION_NYMIC_PREFIX)
			}
		)
	)
end

Info.Necrom =
	QuestSection:new(
	GetString(DQT_NECROM),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_NECROM_QUESTS_WORLDBOSS_01),
				newQuest(DQT_NECROM_QUESTS_WORLDBOSS_02),
				newQuest(DQT_NECROM_QUESTS_WORLDBOSS_03),
				newQuest(DQT_NECROM_QUESTS_WORLDBOSS_04),
				newQuest(DQT_NECROM_QUESTS_WORLDBOSS_05),
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_NECROM_QUESTS_DELVE_01),
				newQuest(DQT_NECROM_QUESTS_DELVE_02),
				newQuest(DQT_NECROM_QUESTS_DELVE_03),
				newQuest(DQT_NECROM_QUESTS_DELVE_04),
			}
		),
		QuestType:new(
			GetString(DQT_BASTION_NYMIC),
			QUEST_TYPE_ENUM.DOLMEN,
			{
				nymicQuest(DQT_NECROM_QUESTS_BASTION_NYMIC_01),
				nymicQuest(DQT_NECROM_QUESTS_BASTION_NYMIC_02),
				nymicQuest(DQT_NECROM_QUESTS_BASTION_NYMIC_03),
				nymicQuest(DQT_NECROM_QUESTS_BASTION_NYMIC_04),
			}
		)
	}
)

Info.EndlessArchive =
	QuestSection:new(
	GetString(DQT_ENDLESSARCHIVE),
	{
		QuestType:new(
			GetString(DQT_ENDLESSARCHIVE_QUESTS_MISC_01),
			QUEST_TYPE_ENUM.MISC,
			{
				newQuest(DQT_ENDLESSARCHIVE_QUESTS_MISC_01),
			}
		)
	}
)

Info.WestWeald =
	QuestSection:new(
	GetString(DQT_WEST_WEALD),
	{
		QuestType:new(
			GetString(DQT_GROUP_BOSS),
			QUEST_TYPE_ENUM.GROUP_BOSS,
			{
				newQuest(DQT_WEST_WEALD_QUESTS_WORLDBOSS_01),
				newQuest(DQT_WEST_WEALD_QUESTS_WORLDBOSS_02),
				newQuest(DQT_WEST_WEALD_QUESTS_WORLDBOSS_03),
				newQuest(DQT_WEST_WEALD_QUESTS_WORLDBOSS_04),
				newQuest(DQT_WEST_WEALD_QUESTS_WORLDBOSS_05),
				newQuest(DQT_WEST_WEALD_QUESTS_WORLDBOSS_06),
			}
		),
		QuestType:new(
			GetString(DQT_DELVE),
			QUEST_TYPE_ENUM.DELVE,
			{
				newQuest(DQT_WEST_WEALD_QUESTS_DELVE_01),
				newQuest(DQT_WEST_WEALD_QUESTS_DELVE_02),
				newQuest(DQT_WEST_WEALD_QUESTS_DELVE_03),
				newQuest(DQT_WEST_WEALD_QUESTS_DELVE_04),
				newQuest(DQT_WEST_WEALD_QUESTS_DELVE_05),
				newQuest(DQT_WEST_WEALD_QUESTS_DELVE_06),
			}
		),
		QuestType:new(
			GetString(DQT_MIRRORMOOR_INCURSION),
			QUEST_TYPE_ENUM.DOLMEN,
			{
				newQuest(DQT_WEST_WEALD_QUESTS_MIRRORMOOR_INCURSION_01),
				-- newQuest(DQT_WEST_WEALD_QUESTS_MIRRORMOOR_INCURSION_02),
			}
		)
	}
)

Info.OtherTimerQuests =
	TimerSection:new(
	GetString(DQT_OTHER_TIMERS),
	{
		TimerQuest:new(GetString(DQT_RANDOM_DUNGEON), TIMER_TYPE.DUNGEON),
		TimerQuest:new(GetString(DQT_RANDOM_BATTLEGROUNDS), TIMER_TYPE.BATTLEGROUNDS),
		TimerQuest:new(GetString(DQT_MOUNT_TRAINING), TIMER_TYPE.MOUNT),
		TimerQuest:new(GetString(DQT_BEQUEATHER), TIMER_TYPE.BEQUEATHER)
	}
)

Info.Pledges = DQT.Pledges.getPledgeSection()

Info.QuestSections = {
	Info.OtherTimerQuests,
	Info.CraftingQuests,
	Info.Pledges,
	-- Info.CyrodiilSettlements,
	-- Info.ImperialCityQuests,
	-- Info.CyrodiilPVP,
	Info.GuildQuests,
	Info.Craglorn,
	Info.ImperialCityQuests,
	Info.WrothgarQuests,
	Info.ThievesGuildQuests,
	Info.DarkBrotherhoodQuests,
	Info.VvardenfellQuests,
	Info.ClockworkCityQuests, -- Added by DarkPhalanx
	Info.SummersetQuests,
	Info.MurkmireQuests,
	Info.ElsweyrQuests,
	Info.DragonHoldQuests, -- Added by DarkPhalanx
	Info.WesternSkyrimQuests, -- Added by DarkPhalanx
	Info.ReachQuests, -- Added by DarkPhalanx
	Info.BlackwoodQuests, -- Added by DarkPhalanx
	Info.DeadlandsQuests, -- Added by g4m3r7ag
	Info.HighIsle, -- Added by g4m3r7ag
	Info.Galen, -- Added by g4m3r7ag
	Info.Necrom, -- Added by notnear
	Info.EndlessArchive, -- Added by notnear
	Info.WestWeald, -- Added by notnear
	Info.CyrodiilSettlements, -- Added by g4m3r7ag
	Info.CyrodiilPVP, -- Added by g4m3r7ag
}
